summaryrefslogtreecommitdiff
path: root/src/components/remote_control/include/remote_control/commands/base_command_request.h
diff options
context:
space:
mode:
authorAlexander Kutsan <akutsan@luxoft.com>2017-08-29 19:09:24 +0300
committerAlexander Kutsan <akutsan@luxoft.com>2017-08-29 19:09:24 +0300
commitcec3cf94c4e4176b6ca636663e7ec5f5251c01f2 (patch)
tree430fdb0ec2b1475aebe65b47d091b6b83d4c3ce6 /src/components/remote_control/include/remote_control/commands/base_command_request.h
parentd52fa061fb97aed5fba074c063bf175431b4d343 (diff)
downloadsdl_core-cec3cf94c4e4176b6ca636663e7ec5f5251c01f2.tar.gz
Fix typo in Aqcuire -> Acquire
Diffstat (limited to 'src/components/remote_control/include/remote_control/commands/base_command_request.h')
-rw-r--r--src/components/remote_control/include/remote_control/commands/base_command_request.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/components/remote_control/include/remote_control/commands/base_command_request.h b/src/components/remote_control/include/remote_control/commands/base_command_request.h
index eb6ea23f74..3fd27861b2 100644
--- a/src/components/remote_control/include/remote_control/commands/base_command_request.h
+++ b/src/components/remote_control/include/remote_control/commands/base_command_request.h
@@ -266,13 +266,13 @@ class BaseCommandRequest
bool CheckDriverConsent();
/**
* @brief AqcuireResources checks whether resource status is busy or not and
* then tries to acquire this resource. In case driver consent is required -
* sends consent request to HMI.
* @return True in case of resource is free and successfully acquired,
* otherwise false
*/
- bool AqcuireResources();
+ bool AcquireResources();
inline bool IsAutoAllowed(application_manager::TypeAccess access) const;
void SendDisallowed(application_manager::TypeAccess access);
void SendGetUserConsent(const Json::Value& value);
@@ -266,13 +266,13 @@ class BaseCommandRequest
bool CheckDriverConsent();
/**
- * @brief AqcuireResources checks whether resource status is busy or not and
+ * @brief AcquireResources checks whether resource status is busy or not and
* then tries to acquire this resource. In case driver consent is required -
* sends consent request to HMI.